from setuptools import setup

setup(
    name='jsvn_qa_utils_rest',
    version='1.0.2',
    packages=['jsvn_qa_utils_rest', 'jsvn_qa_utils_rest.src'],
    url='',
    license='',
    author='filipp.chachin',
    author_email='codejseven@gmail.com',
    description='test'
)
